/* XPM data for toolbar icons */
/* XPM */

static char * a_xpm[] = {
"20 20 6 1",
" 	c #FFFFFFFFFFFF",
".	c #000000000000",
"X	c #BABAC1C1FFFF",
"o	c #00000000FFFF",
"O	c #7D7D9797FFFF",
"+	c #1A1AB3B32020",
"                    ",
"       ......       ",
"     ..      ..     ",
"    .       XXX.    ",
"   .       oooX .   ",
"  .        XooX  .  ",
"  .       XoXo   .  ",
" .       XoX      . ",
" .       OX       . ",
" .      + +       . ",
" .       + ++ ++ +. ",
" .      + +       . ",
" .                . ",
"  .              .  ",
"  .              .  ",
"   .            .   ",
"    .          .    ",
"     ..      ..     ",
"       ......       ",
"                    "};
/* XPM */
static char * b_xpm[] = {
"20 20 5 1",
" 	c #FFFFFFFFFFFF",
".	c #000000000000",
"X	c #BEFBC30BFFFF",
"o	c #00000000FFFF",
"O	c #79E79658FFFF",
"                    ",
" .................. ",
" .             XXX. ",
" .            oooX. ",
" .            XooX. ",
" .           XoXo . ",
" .          XoX   . ",
" .          OX    . ",
" .                . ",
" .                . ",
" .                . ",
" .                . ",
" .                . ",
" .                . ",
" .                . ",
" .                . ",
" .                . ",
" .                . ",
" .................. ",
"                    "};
/* XPM */
static char * bd_xpm[] = {
"20 20 3 1",
" 	c #FFFF00000000",
".	c #FFFFFFFFFFFF",
"X	c #000000000000",
"                    ",
" .................. ",
" .................. ",
"XXXXXXXXXXXXXXXXXXXX",
"XXXXXXXXXXXXXXXXXXXX",
" .................. ",
" .................. ",
" .................. ",
" .................. ",
"XXX..XXXX..XXXX..XXX",
"XXX..XXXX..XXXX..XXX",
" .................. ",
" .................. ",
" .................. ",
" .................. ",
".XX..XX..XX..XX..XX.",
".XX..XX..XX..XX..XX.",
" .................. ",
" .................. ",
"                    "};
/* XPM */
static char * ccw_xpm[] = {
"20 20 5 1",
" 	c #FFFFFFFFFFFF",
".	c #B6DAB2CAB6DA",
"X	c #000000000000",
"o	c #79E77DF779E7",
"O	c #618565956185",
"                    ",
"     .              ",
"     X  ..          ",
"    .XXXXXXo        ",
"    XXXXXXXXXo      ",
"   .XXo.   .XXX     ",
"   XXXXXO    XXo    ",
"   XX...      XX    ",
"  ..          .Xo   ",
"               XX.  ",
"   .           XX.  ",
"  XX           XX   ",
"  oXo         .Xo   ",
"   XX         XX    ",
"   oXX       XXo    ",
"    XXX.   .XXX     ",
"     oXXXXXXXo      ",
"       XXXXo        ",
"        ..          ",
"                    "};
/* XPM */
static char * co_xpm[] = {
"20 20 5 1",
" 	c #000000000000",
".	c #FFFF00000000",
"X	c #00000000FFFF",
"o	c #FFFFFFFF0000",
"O	c #0000FFFF0000",
"                    ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" .........XXXXXXXXX ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
" oooooooooOOOOOOOOO ",
"                    "};
/* XPM */
static char * cp_xpm[] = {
"20 20 7 1",
" 	c #FFFFFFFFFFFF",
".	c #000000000000",
"X	c #B6DAB2CAB6DA",
"o	c #FFFF82078617",
"O	c #FFFF00000000",
"+	c #79E77DF779E7",
"@	c #618565956185",
"      .             ",
"      .X            ",
"     X..    ooO     ",
" XXXX...XX++ OOO    ",
"  .........    OO   ",
"   ......+      Oo  ",
"    X...+        O  ",
"    X...++       O  ",
"    .....+     O O o",
"   @..  ..X     OOO ",
"  X@+    X@X .  OO  ",
"             .X O   ",
"            X..o    ",
"        XXXX...XX++ ",
"         .........  ",
"          ......+   ",
"           X...+    ",
"           .....++  ",
"          @..  ..+  ",
"         X@+    X+X "};
/* XPM */
static char * cw_xpm[] = {
"20 20 5 1",
" 	c #FFFFFFFFFFFF",
".	c #B6DAB2CAB6DA",
"X	c #000000000000",
"o	c #79E77DF779E7",
"O	c #618565956185",
"                    ",
"              .     ",
"          ..  X     ",
"        oXXXXXX.    ",
"      oXXXXXXXXX    ",
"     XXX.   .oXX.   ",
"    oXX    OXXXXX   ",
"    XX      ...XX   ",
"   oX.          ..  ",
"  .XX               ",
"  .XX           .   ",
"   XX           XX  ",
"   oX.         oXo  ",
"    XX         XX   ",
"    oXX       XXo   ",
"     XXX.   .XXX    ",
"      oXXXXXXXo     ",
"        oXXXX       ",
"          ..        ",
"                    "};
/* XPM */
static char * d2_xpm[] = {
"20 20 5 1",
" 	c #FFFFFFFFFFFF",
".	c #FFFF00000000",
"X	c #BEFBBEFBBEFB",
"o	c #000000000000",
"O	c #79E77DF779E7",
"      ..            ",
"      ..    .       ",
"       .   ..       ",
"       .   .        ",
" XoX      .         ",
"   OoX              ",
"    OoOO       Xooo ",
"     XoooO    Xo  Xo",
"       Xooo  Xo    o",
"         Ooo Oo  OoX",
"ooooooooooo oooooX  ",
"XXooooooooooooo     ",
"    XXXXXXXX   oX   ",
"              o Oo  ",
"    .  .     Xo   o ",
"   .   .     Xo   o ",
"  ..   .      Xooo  ",
"  .    ..           ",
"       ..           ",
"                    "};
/* XPM */
static char * e_xpm[] = {
"20 20 5 1",
" 	c #FFFFFFFFFFFF",
".	c #000000000000",
"X	c #BEFBC30BFFFF",
"o	c #00000000FFFF",
"O	c #79E79658FFFF",
"                    ",
" ... ..  ..  ..  .. ",
" .  ..            . ",
" .    ..            ",
" .      ..          ",
" .        ..      . ",
" .          ..    . ",
" .        XXX.      ",
" .       oooX .     ",
" .       XooX .   . ",
" .      XoXo   .  . ",
" .     XoX     .    ",
" .     OX       .   ",
" .              . . ",
" .               .. ",
" .               .  ",
" .                . ",
" .                . ",
" .................. ",
"                    "};
/* XPM */
static char * fi_xpm[] = {
"20 20 3 1",
" 	c #FFFF00000000",
".	c #000000000000",
"X	c #FFFFFFFFFFFF",
"                    ",
" .X.X.X.X.XXXX.XXXX ",
" X.X.X.X.XX.XXXX.XX ",
" .X.X.X.X.XXX.XXXX. ",
" X.X.X.X.X.XXXX.XXX ",
" .X.X.X.X.XX.XXXX.X ",
" X.X.X.X.XXXXX.XXXX ",
" .X.X.X.X.X.XXXX.XX ",
" X.X.X.X.XXXX.XXXX. ",
" .X.X.X.X..XXXX.XXX ",
" ..X..X..X......... ",
" ..X..X..XXXXXXXXXX ",
" X..X..X........... ",
" X..X..X..XXXXXXXXX ",
" .X..X..X.......... ",
" .X..X..X.XXXXXXXXX ",
" ..X..X..X......... ",
" ..X..X..XXXXXXXXXX ",
" X..X..X........... ",
"                    "};
/* XPM */
static char * fx_xpm[] = {
"20 20 8 1",
" 	c #FFFF00000000",
".	c #FFFFA3A3A3A3",
"X	c #FFFFFFFFFFFF",
"o	c #FFFFFFFF0000",
"O	c #FFFFD7D70000",
"+	c #C1C1C6C6FFFF",
"@	c #00000000FFFF",
"#	c #8E8E9999FFFF",
"       .XXXXXXXXXXXX",
" oooooO  XX++XXXXXXX",
".Ooooooo .X@@@XXXXXX",
"X ooooooO X+#@@XXXXX",
"X OooooooO XXX@#X#XX",
"X OooooooO XXXX@#+XX",
"X ooooooO XXX+@@@+XX",
".Ooooooo .XXXXX@@+XX",
" oooooO  XXXXXXX@+XX",
"       .XXXXXXXXX+XX",
"XXXXXXXXXXXX.       ",
"XXXXXXXXXXX  oooooo ",
"XXXXXXXXXX. ooooooO.",
"XXXXXXXXXX Ooooooo X",
"XXXXXXXXX OooooooO X",
"XXXXXXXXX OooooooO X",
"XXXXXXXXXX Ooooooo X",
"XXXXXXXXXX. ooooooO.",
"XXXXXXXXXXX  Oooooo ",
"XXXXXXXXXXXX.       "};
/* XPM */
static char * pz_xpm[] = {
"20 20 7 1",
" 	c #B0B0FFFF4C4C",
".	c #C0C0C0C0C0C0",
"X	c #000000000000",
"o	c #FFFFFFFF0000",
"O	c #7F7F7F7F0000",
"+	c #B2B2BFBF1515",
"@	c #808080808080",
"      .X X.         ",
"        X    XXX.   ",
"       XoX. XoooX.  ",
"      XXooX OooooX  ",
"        +ooXoooo+@  ",
".   X   Xoo+ooooX   ",
"X  X@.  Ooooo@XX    ",
" X@ooXOOoooooX     .",
".@Xooo+oooooo.X   .X",
"X  Xoooooooooo.X .X ",
"    X+ooooOXXooo@X  ",
"     XoooO   XoX  X ",
"  XXO+oooX    X    X",
" XooooOooX   O     .",
" XoooX +o+XO       X",
" X+ooX Xoo@       X ",
"  XX@  .@X       X  ",
"        X        X  ",
"      .X.O  XX    . ",
"     .X   OX  X   XX"};
/* XPM */
static char * li_xpm[] = {
"20 20 8 1",
" 	c #0000FFFFFFFF",
".	c #28A2AEBAFFFF",
"X	c #000000000000",
"o	c #BEFBBEFBBEFB",
"O	c #79E77DF779E7",
"+	c #FFFFFFFFFFFF",
"@	c #79E765951861",
"#	c #FFFFC30B30C2",
"     ...   ...      ",
"XXooOo+OXXXO++OooXX ",
"X+ooo++++Xoo++++++@ ",
"X+oooOO++OooXX++++@ ",
"X+oXO++O+OoX++OOO+@ ",
"X+oooOO++OooXX++++@ ",
"X+oXO++O+OoX++OOO+@ ",
"X+oooOO++OooXX++++@ ",
"X+oXO++O+OoX++OOO+@ ",
"X+oooOO++OooXX++++@ ",
"X+oXO++O+OoX++OOO+@ ",
"X+oooOO++OooXX++++@ ",
"X+oXO++O+OoX++OOO+@ ",
"X+oooOO++OooXX++++@ ",
"X+oXO++O+OoX++OOO+@ ",
"X+ooo++++Ooo++++++@ ",
"X+oooOOO+OoOOOo+++@ ",
"XOOO####OOO####OOO@ ",
"X########@########@ ",
"XXXXXXXOXXXOXXXXXXX "};
/* XPM */
static char * mk_xpm[] = {
"20 20 10 1",
" 	c #FFFFFFFFFFFF",
".	c #000000000000",
"X	c #B6DAB2CAB6DA",
"o	c #FFFF82078617",
"O	c #FFFF00000000",
"+	c #79E77DF779E7",
"@	c #618565956185",
"#	c #BEFBBEFBBEFB",
"$	c #FFFF92488E38",
"%	c #FFFFC30B30C2",
"      .             ",
"      .X            ",
"     X..    ooO     ",
" XXXX...XX++ OOO    ",
"  .........    OO   ",
"   ......+      Oo  ",
"    X...+        O  ",
"    X...++       O  ",
"    .....+     O O o",
"   @..  ..X     OOO ",
"  X@+    X@X    OO  ",
"          ... ..O   ",
"       ...#  .#$ ...",
"       .###+ +#+   .",
"       .#++  +# ++ .",
"       .###+ +#+   .",
"       .#++  +# ++ .",
"       .###  +#    .",
"       .##...+...  .",
"       ...%%%.%%%..."};
/* XPM */
static char * po2_xpm[] = {
"20 20 4 1",
" 	c #FFFFFFFFFFFF",
".	c #00000000FFFF",
"X	c #000000000000",
"o	c #28A2AEBAFFFF",
"         .          ",
"        ...         ",
"       .....        ",
"      .......       ",
"     .........      ",
"    ...........     ",
"   .............    ",
"  ...............   ",
"       .....        ",
"       .....        ",
"       .....        ",
"XXXXXXXXXXXXXXXXXXXX",
"       ooooo        ",
"       ooooo        ",
"       ooooo        ",
"       ooooo        ",
"       ooooo        ",
"       ooooo        ",
"       ooooo        ",
"       ooooo        "};
/* XPM */
static char * pu2_xpm[] = {
"20 20 4 1",
" 	c #FFFFFFFFFFFF",
".	c #00000000FFFF",
"X	c #000000000000",
"o	c #28A2AEBAFFFF",
"       .....        ",
"       .....        ",
"       .....        ",
"       .....        ",
"       .....        ",
"       .....        ",
"       .....        ",
"       .....        ",
"XXXXXXXXXXXXXXXXXXXX",
"       ooooo        ",
"       ooooo        ",
"       ooooo        ",
"  ooooooooooooooo   ",
"   ooooooooooooo    ",
"    ooooooooooo     ",
"     ooooooooo      ",
"      ooooooo       ",
"       ooooo        ",
"        ooo         ",
"         o          "};

/* XPM */
static char * i_xpm[] = {
"20 20 6 1",
" 	c #00000000FFFF",
".	c #80808080FFFF",
"X	c #FFFFFFFFFFFF",
"o	c #C0C0C0C0FFFF",
"O	c #6C6C7575FFFF",
"+	c #40404040FFFF",
"                    ",
"          .XXo      ",
"         OXXXX.     ",
"         oXXXXo     ",
"         .XXXX      ",
"          .oX.      ",
"                    ",
"         .oXX+      ",
"       oXXXXo       ",
"        .XXXo       ",
"         XXX        ",
"        .XXX        ",
"        oXXo        ",
"        oXX.        ",
"       .XXX         ",
"       .XXo .o.     ",
"       oXXo.Xo      ",
"       oXXXXo       ",
"        .XXo +      ",
"                    "};

/* XPM */
static char * s_xpm[] = {
"20 20 6 1",
" 	c #FFFFFFFFFFFF",
".	c #1861B2CA2081",
"X	c #618565956185",
"o	c #000000000000",
"O	c #B6DAB2CAB6DA",
"+	c #79E77DF779E7",
"   .                ",
"   .                ",
"   .                ",
"   .  XooXO         ",
"   . ooO Oo+        ",
"   .OO     o        ",
"   .o      o        ",
"   XO      o        ",
"  .o.     Oo        ",
"   o      O+        ",
"  . .     o       ..",
"         o+     ..  ",
"        ++    ..    ",
"       +O   ..      ",
"      O+  ..        ",
"      o ..          ",
"     oO.            ",
". .oXO              ",
" .X.                ",
". .                 "};

static char * t_xpm[] = {
"20 20 6 1",
" 	c #FFFFFFFFFFFF",
".	c #1A1AB3B32020",
"X	c #B3B3B3B3B3B3",
"o	c #000000000000",
"O	c #666666666666",
"+	c #7F7F7F7F7F7F",
"                   .",
"       Xoo         .",
"        ooX        .",
"         oo        .",
"         ooX       .",
"        OooO       .",
"        oXoo       .",
"       Oo ooX      .",
"       O   oo      .",
"      Xo   XoX     .",
"      oO   Xoo     .",
"     Xo     XoX    .",
"     OX     XoO    .",
"    Xo++++++Xoo    .",
"    OooooooooooX   .",
"   Xo+       XoO   .",
"   Oo+        ooX  .",
"  Xoo         OoOX .",
" XooO+       +ooo+X.",
"+ooooo+     Xoooooo."};
/* XPM */
static char * uj_xpm[] = {
"20 20 6 1",
" 	c #B0B0FFFF4C4C",
".	c #7F7F7F7F0000",
"X	c #000000000000",
"o	c #8484B3B31111",
"O	c #C0C0C0C0C0C0",
"+	c #808080808080",
"    ..   Xo         ",
".       Xo    ..    ",
" .     oXX   XXX.   ",
" X    oXXXX oXXXX   ",
".X     ooXXXoXXXX   ",
"    X    XXXXXXXo   ",
"   XX    XXXXXoo    ",
". XXX.  XXXXXX     O",
" X.XXXXXXXXXXXX   OX",
"X  oXXXXXXXXXXXX OX ",
"    oXXXXX+oXXXX+X  ",
"     XXXX+   XXX  X ",
"  oXXXXXXo    X    X",
" XXXXXoXXo   o     O",
" XXXXX XXXXo     ooX",
" oXXX  .XXX      oX ",
"  oXo   oX       o  ",
"        X        X  ",
"      OXX  oXX    O ",
"     OX .X X  X   XX"};
/* XPM */
static char * fy_xpm[] = {
"20 20 8 1",
" 	c #FFFFFFFFFFFF",
".	c #FFFF00000000",
"X	c #FFFFA3A3A3A3",
"o	c #FFFFFFFF0000",
"O	c #FFFFD7D70000",
"+	c #C1C1C6C6FFFF",
"@	c #00000000FFFF",
"#	c #8E8E9999FFFF",
" ..X    X..         ",
" .oO....Oo. ++      ",
" .oooOOooo. @@@     ",
" .oooooooo. +#@@    ",
" .oooooooo.    @# # ",
" .oooooooo.     @#+ ",
" .OooooooO.   +@@@+ ",
" X.oooooo.X     @@+ ",
"  ..OooO..       @+ ",
"   X.OO.X     ..  + ",
"     ..     X.OO.X  ",
"           ..OooO.. ",
"          X.oooooo.X",
"          .OooooooO.",
"          .oooooooo.",
"          .oooooooo.",
"          .oooooooo.",
"          .oooOOooo.",
"          .oO....Oo.",
"          ..X    X.."};
/* XPM */
static char * yp_xpm[] = {
"20 20 7 1",
" 	c #0000FFFFFFFF",
".	c #79E765951861",
"X	c #000000000000",
"o	c #FFFFFFFF0000",
"O	c #FFFFC30B30C2",
"+	c #FFFFFFFFFFFF",
"@	c #79E77DF779E7",
"    ....   ....     ",
"XX..oooo.X.Oooo..XX ",
"X+oooooooXOOoooooO. ",
"X+ooo.oooXOOo.oooO. ",
"X+o.ooo.oXO.ooo.oO. ",
"X+ooo.oooXOOo.oooO. ",
"X+o.ooo.oXO.ooo.oO. ",
"X+ooo.oooXOOo.oooO. ",
"X+o.ooo.oXO.ooo.oO. ",
"X+ooo.oooXOOo.oooO. ",
"X+o.ooo.oXO.ooo.oO. ",
"X+ooo.oooXOOo.oooO. ",
"X+o.ooo.oXO.ooo.oO. ",
"X+ooo.oooXOOo.oooO. ",
"X+o.ooo.oXOOooo.oO. ",
"X+oooooooXOOoooooO. ",
"X+oo....oXO....ooO. ",
"XO..++++.X.++++..O. ",
"X++++++++.++++++++. ",
"XXXXXXX@XXX@XXXXXXX "};
/* XPM */
static char * z4_xpm[] = {
"20 20 7 1",
" 	c #FFFFFFFFFFFF",
".	c #666666666666",
"X	c #D9D9D9D9D9D9",
"o	c #000000000000",
"O	c #A2A2B5B5CDCD",
"+	c #79797D7D7979",
"@	c #20208989B3B3",
"                    ",
" .XX            XX. ",
" Xooo.O      O+oooX ",
" XooOX        XOooX ",
"  oOoX        XoOo  ",
"  .XXoX      XoXX.  ",
"  O  XoX    XoX  O  ",
"      Xo    oX      ",
"        O  O        ",
"         XX         ",
"         XX         ",
"        O  O        ",
"      Xo    oX      ",
"  O  XoX    XoX  O  ",
"  .XXoX      XoXX.  ",
"  oOoX        XoOo  ",
" Xoo@X        XOooX ",
" Xooo.O      O.oooX ",
" .XX            XX. ",
"                    "};
/* XPM */
static char * z5_xpm[] = {
"20 20 6 1",
" 	c #000000000000",
".	c #FFFFFFFFFFFF",
"X	c #79797D7D7979",
"o	c #A2A2B5B5CDCD",
"O	c #D9D9D9D9D9D9",
"+	c #666666666666",
" ...................",
"..X.............XX..",
".X o............o X.",
"..o O..........O o..",
"...O O..o..o..O O...",
"....O O. .. .O O....",
".....O O .. O O.....",
"......O  OO  O......",
"....o    OO    o....",
".......OOooOO.......",
".......OOooOO.......",
"....o    OO    o....",
"......O  OO  O......",
".....O O .. O O.....",
"....O O. .. .O O....",
"...O O..o..o..O O...",
"..o O..........O o..",
".+ o............o X.",
"..X..............X..",
"...................."};
/* XPM */
static char * pl_xpm[] = {
"20 20 7 1",
" 	c #A2A2B5B5CDCD",
".	c #00000000FFFF",
"X	c #3D3DC4C4FFFF",
"o	c #0000FFFFFFFF",
"O	c #000000000000",
"+	c #FFFFFFFFFFFF",
"@	c #79797D7D7979",
"    ....   ....     ",
"Xo..oooo.O.Xooo..OO ",
"OooooooooOXXoooooX. ",
"Ooooo.XooOXXo.oooX. ",
"OoX.Xoo.oOX.XoX.oX. ",
"Ooooo.XooOXXo.oooX. ",
"OoX.Xoo.oOX.XoX.oX. ",
"Ooooo.XooOXXo.oooX. ",
"OoX.Xoo.oOX.XoX.oX. ",
"Ooooo.XooOXXo.oooX. ",
"OoX.Xoo.oOX.XoX.oX. ",
"Ooooo.XooOXXo.oooX. ",
"OoX.Xoo.oOX.XoX.oX. ",
"Ooooo.XooOXXo.oooX. ",
"OoX.Xoo.oOX.XoX.oX. ",
"OooooooooOXXoooooX. ",
"Oooo....oOX....ooX. ",
"OX..++++.O.++++..X. ",
" ++++++++.++++++++X ",
"OOOOOOO@OOO@OOOOOO  "};
/* XPM */
static char * pm_xpm[] = {
"20 20 9 1",
" 	c #000000000000",
".	c #808080808080",
"X	c #FFFF00000000",
"o	c #FFFFFFFFFFFF",
"O	c #C0C0C0C0C0C0",
"+	c #FFFFB7B7C1C1",
"@	c #00000000FFFF",
"#	c #B3B3CACAFFFF",
"$	c #7F7F8E8EFFFF",
"     .     XXXXXXXXX",
"     o     XXXXXXXXX",
"    OoO    ++XXXXXXX",
"    oOo   Oooo+XXXXX",
"   .o.o.   XXooX+XXX",
"   Oo oO   XXXo+oXXX",
"  .ooooo.  X+X+ooXXX",
"  Oo   oO  XX+oooXXX",
"  o.   .o  XXXXX+XXX",
".ooo   ooo.@@@@@@@@@",
"           ooooo#@@@",
"XXXXXXXXX@@@o$@$$#@@",
"XXXXXXXXX@@@o$@@@o$@",
"XXXXXXXXX@@@o$@@$o@@",
"XXXXXXXXX@@@oooo#@@@",
"XXXXXXXXX@@@o$@@$o@@",
"XXXXXXXXX@@@o$@@@o$@",
"XXXXXXXXX@@@o$@$$#@@",
"XXXXXXXXX@@ooooo#@@@",
"XXXXXXXXX@@@@@@@@@@@"};
